HnswFlags class

Flags as a part of the HnswIndex configuration.

Constructors

HnswFlags({bool debugLogs = false, bool debugLogsDetailed = false, bool vectorCacheSimdPaddingOff = false, bool reparationLimitCandidates = false})
Create flags for the HnswIndex annotation.
const

Properties

debugLogs → bool
Enables debug logs.
final
debugLogsDetailed → bool
Enables "high volume" debug logs, e.g. individual gets/puts.
final
hashCode → int
The hash code for this object.
no setterinherited
reparationLimitCandidates → bool
If the speed of removing nodes becomes a concern in your use case, you can speed it up by setting this flag.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vectorCacheSimdPaddingOff → bool
Padding for SIMD is enabled by default, which uses more memory but may be faster. This flag turns it off.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited